@@ -398,22 +398,21 @@ class LoadMaster(HttpClient):
         """enable LoadMaster API"""
         # Can't use the HttpClient methods for this as the
         # endpoint is different when attempting to enable the API.
-        url = ("https://{user}:{pw}@{ip}:{port}"
-               "/progs/doconfig/enableapi/set/yes").format(user=self.username,
-                                                           pw=self.password,
-                                                           ip=self.ip_address,
-                                                           port=self.port)
         try:
-            #self._tls_session = Session()
-            #self._tls_session.mount("http://",
-                                    #UseTlsAdapter(self._tls_version))
             if self.cert:
-                self._tls_session.get(url, verify=False, timeout=1,
-                                      cert=self.cert)
+                url = ("https://{ip}:{port}/progs/doconfig/enableapi/set/yes".
+                       format(ip=self.ip_address, port=self.port))
+                resp = self._tls_session.get(url, verify=False, timeout=1,
+                                             cert=self.cert)
             else:
-                self._tls_session.get(url, verify=False, timeout=1,
-                                      cert=self.cert)
+                url = ("https://{user}:{pw}@{ip}:{port}/progs/doconfig/"
+                       "enableapi/set/yes").format(user=self.username,
+                                                   pw=self.password,
+                                                   ip=self.ip_address,
+                                                   port=self.port)
+                resp = self._tls_session.get(url, verify=False, timeout=1)
             self._tls_session.close()
+            resp.raise_for_status()
             return True
         except exceptions.RequestException:
             return False
@@ -553,6 +552,8 @@ class LoadMaster(HttpClient):
         except KempTechApiException as e:
             if str(e) == "User already exists.":
                 raise UserAlreadyExistsException(user, self.ip_address)
+            else:
+                raise
         return send_response(response)
 
     def delete_local_user(self, user):
